ploneintranet.userprofile.browser package
=========================================

Submodules
----------

ploneintranet.userprofile.browser.userprofile module
----------------------------------------------------

.. automodule:: ploneintranet.userprofile.browser.userprofile
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: ploneintranet.userprofile.browser
    :members:
    :undoc-members:
    :show-inheritance:
